@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '2.88';
+$CPAN::Perl::Releases::VERSION = '3.06';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -182,6 +182,19 @@ our $data =
 "5.25.3" => { id => 'SHAY' },
 "5.22.3-RC2" => { id => 'SHAY' },
 "5.24.1-RC2" => { id => 'SHAY' },
+"5.22.3-RC3" => { id => 'SHAY' },
+"5.24.1-RC3" => { id => 'SHAY' },
+"5.25.4" => { id => 'BINGOS' },
+"5.25.5" => { id => 'STEVAN' },
+"5.22.3-RC4" => { id => 'SHAY' },
+"5.24.1-RC4" => { id => 'SHAY' },
+"5.25.6" => { id => 'ARC' },
+"5.25.7" => { id => 'EXODIST' },
+"5.25.8" => { id => 'XSAWYERX' },
+"5.22.3-RC5" => { id => 'SHAY' },
+"5.24.1-RC5" => { id => 'SHAY' },
+"5.22.3" => { id => 'SHAY' },
+"5.24.1" => { id => 'SHAY' },
 };
 
 sub perl_tarballs {
@@ -249,7 +262,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 2.88
+version 3.06
 
 =head1 SYNOPSIS
 
@@ -316,7 +329,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Chris Williams.
+This software is copyright (c) 2017 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
